@@ -126,6 +126,16 @@ bool supports_nonascii_internal()
     return SUPPORTS_NON_ASCII;
 }
 
+// [[Rcpp::export(rng = false)]]
+bool compiled_with_gcc_internal()
+{
+#if defined(__GNUC__) && !defined(__clang__)
+    return true;
+#else
+    return false;
+#endif
+}
+
 // [[Rcpp::export(rng = false)]]
 bool take_as_utf8()
 {
